==> ons-api-1.2.1-sources.jar: com/aliyun/openservices/ons/api/PropertyKeyConst.java <==
package com.aliyun.openservices.ons.api;

public class PropertyKeyConst {
    public static final String MessageModel = "MessageModel";

    public static final String ProducerId = "ProducerId";

    public static final String ConsumerId = "ConsumerId";

    public static final String AccessKey = "AccessKey";

    public static final String SecretKey = "SecretKey";

    public static final String SendMsgTimeoutMillis = "SendMsgTimeoutMillis";

    // 地址服务器
    public static final String ONSAddr = "ONSAddr";

    // Name Server地址
    public static final String NAMESRV_ADDR = "NAMESRV_ADDR";

    // 消费线程数量
    public static final String ConsumeThreadNums = "ConsumeThreadNums";

    // 设置 ECS 渠道
    public static final String OnsChannel = "OnsChannel";
    // 设置为Notify、Metaq
    public static final String MQType = "MQType";
    // 是否启动vip channel
    public static final String isVipChannelEnabled = "isVipChannelEnabled";
    // 顺序消息消费失败进行重试前的等待时间
    public static final String SuspendTimeMillis = "suspendTimeMillis";
    // 消息消费失败时的最大重试次数
    public static final String MaxReconsumeTimes = "maxReconsumeTimes";
    // 一条消息消费的超时时间
    public static final String ConsumeTimeout = "consumeTimeout";

    // mqtt
    public static final String MqttMessageId = "mqttMessageId";
    public static final String MqttMessage = "mqttMessage";
    public static final String MqttPublishRetain = "mqttRetain";
    public static final String MqttPublishDubFlag = "mqttPublishDubFlag";
    public static final String MqttSecondTopic = "mqttSecondTopic";
    public static final String MqttClientId = "mqttClientId";
    public static final String MqttQOS = "qoslevel";
}

==> ons-api-1.2.3-sources.jar: com/aliyun/openservices/ons/api/PropertyKeyConst.java <==
package com.aliyun.openservices.ons.api;

public class PropertyKeyConst {
    public static final String MessageModel = "MessageModel";

    public static final String ProducerId = "ProducerId";

    public static final String ConsumerId = "ConsumerId";

    public static final String AccessKey = "AccessKey";

    public static final String SecretKey = "SecretKey";

    public static final String SendMsgTimeoutMillis = "SendMsgTimeoutMillis";

    // 地址服务器
    public static final String ONSAddr = "ONSAddr";

    // Name Server地址
    public static final String NAMESRV_ADDR = "NAMESRV_ADDR";

    // 消费线程数量
    public static final String ConsumeThreadNums = "ConsumeThreadNums";

    // 设置 ECS 渠道
    public static final String OnsChannel = "OnsChannel";
    // 设置为Notify、Metaq
    public static final String MQType = "MQType";
    // 是否启动vip channel
    public static final String isVipChannelEnabled = "isVipChannelEnabled";
    // 顺序消息消费失败进行重试前的等待时间 单位(毫秒)
    public static final String SuspendTimeMillis = "suspendTimeMillis";
    // 消息消费失败时的最大重试次数
    public static final String MaxReconsumeTimes = "maxReconsumeTimes";
    // 设置每条消息消费的最大超时时间,超过这个时间,这条消息将会被视为消费失败,等下次重新投递再次消费. 每个业务需要设置一个合理的值. 单位(分钟)
    public static final String ConsumeTimeout = "consumeTimeout";

    // mqtt
    public static final String MqttMessageId = "mqttMessageId";
    public static final String MqttMessage = "mqttMessage";
    public static final String MqttPublishRetain = "mqttRetain";
    public static final String MqttPublishDubFlag = "mqttPublishDubFlag";
    public static final String MqttSecondTopic = "mqttSecondTopic";
    public static final String MqttClientId = "mqttClientId";
    public static final String MqttQOS = "qoslevel";
}
